@@ -1,4 +1,8 @@
+from functools import wraps
+
+
 def error_processing(func):
+    @wraps(func)
     def wrapper(*args, **kwargs):
         try:
             return func(*args, **kwargs)
